@@ -15,8 +15,9 @@
 #include <cinttypes>
 
 #if QWT_VERSION >= 0x060000
-#include <qwt_compat.h>
-#include <qwt_point_3d.h> // doesn't seem necessary, but is...
+#include <qwt_interval.h>
+
+typedef QwtInterval QwtDoubleInterval;
 #endif
 
 class TimeRasterData : public QwtRasterData
@@ -35,6 +36,9 @@ public:
 #if QWT_VERSION < 0x060000
     virtual QwtDoubleInterval range() const;
     virtual void setRange(const QwtDoubleInterval&);
+#elif QWT_VERSION >= 0x060200
+    virtual QwtInterval interval(Qt::Axis) const;
+    void setInterval(Qt::Axis, const QwtInterval&);
 #endif
 
     double value(double x, double y) const override;
@@ -47,10 +51,10 @@ public:
     void incrementResidual();
 
 protected:
-    double* d_data;
+    std::vector<double> d_data;
     double d_rows, d_cols;
     double d_resid;
-    int d_nitems, d_totalitems, d_data_size;
+    int d_nitems, d_totalitems;
 
 #if QWT_VERSION < 0x060000
     QwtDoubleInterval d_intensityRange;
@@ -58,6 +62,10 @@ protected:
     QwtInterval d_intensityRange;
 #endif
 
+#if QWT_VERSION >= 0x060200
+    QwtInterval d_intervals[3];
+#endif
+
 private:
 };
 
